;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vhdl-ext" "20251009.1205"
  "VHDL Extensions."
  '((emacs        "29.1")
    (vhdl-ts-mode "0.3.2")
    (lsp-mode     "8.0.0")
    (ag           "0.48")
    (ripgrep      "0.4.0")
    (hydra        "0.15.0")
    (flycheck     "32")
    (async        "1.9.7"))
  :url "https://github.com/gmlarumbe/vhdl-ext"
  :commit "abaeede75309794b6d104af2d387452f148e5ca4"
  :revdesc "abaeede75309"
  :keywords '("vhdl" "ide" "tools")
  :authors '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com"))
  :maintainers '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com")))
